==> egroupware_1.4.004-2.dfsg.orig.tar.gz: egroupware-1.4.004-2.dfsg/phpgwapi/js/fckeditor/fckeditor.egwconfig.js <==
FCKConfig.ToolbarSets["egw_simple"] = [
	['Bold','Italic','Underline'],
	['JustifyLeft','JustifyCenter','JustifyRight','JustifyFull'],
	['UnorderedList','OrderedList','Outdent','Indent','Undo','Redo'],
	['FitWindow'],
	'/',
	['FontFormat','FontName','FontSize'],
	['TextColor','BGColor']
] ;
FCKConfig.ToolbarSets["egw_simple_spellcheck"] = [
	['Bold','Italic','Underline'],
	['JustifyLeft','JustifyCenter','JustifyRight','JustifyFull'],
	['UnorderedList','OrderedList','Outdent','Indent','Undo','Redo'],
	['FitWindow','SpellCheck'],
	'/',
	['FontFormat','FontName','FontSize'],
	['TextColor','BGColor']
] ;
FCKConfig.ToolbarSets["egw_extended"] = [
	['Bold','Italic','Underline'],
	['JustifyLeft','JustifyCenter','JustifyRight','JustifyFull'],
	['UnorderedList','OrderedList','Outdent','Indent','Undo','Redo'],
	['Link','Unlink','Anchor'],
	['Find','Replace'],
	['FitWindow','Image','Table'],
	'/',
	['FontFormat','FontName','FontSize'],
	['TextColor','BGColor']
] ;
FCKConfig.ToolbarSets["egw_extended_spellcheck"] = [
	['Bold','Italic','Underline'],
	['JustifyLeft','JustifyCenter','JustifyRight','JustifyFull'],
	['UnorderedList','OrderedList','Outdent','Indent','Undo','Redo'],
	['Link','Unlink','Anchor'],
	['Find','Replace'],
	['FitWindow','SpellCheck','Image','Table'],
	'/',
	['FontFormat','FontName','FontSize'],
	['TextColor','BGColor']
] ;
FCKConfig.ToolbarSets["egw_advanced"] = [
	['Source','DocProps','-','Save','NewPage','Preview','-','Templates'],
	['Cut','Copy','Paste','PasteText','PasteWord','-','Print'],
	['Undo','Redo','-','Find','Replace','-','SelectAll','RemoveFormat'],
	'/',
	['Bold','Italic','Underline','StrikeThrough','-','Subscript','Superscript'],
	['JustifyLeft','JustifyCenter','JustifyRight','JustifyFull'],
	['UnorderedList','OrderedList','-','Outdent','Indent'],
	['Link','Unlink','Anchor'],
	['FitWindow','Image',/*'Flash',*/'Table','Rule',/*'Smiley',*/'SpecialChar','PageBreak'], //,'UniversalKey'
	'/',
	['Style','FontFormat','FontName','FontSize'],
	['TextColor','BGColor']
] ;
FCKConfig.ToolbarSets["egw_advanced_spellcheck"] = [
	['Source','DocProps','-','Save','NewPage','Preview','-','Templates'],
	['Cut','Copy','Paste','PasteText','PasteWord','-','Print','SpellCheck'],
	['Undo','Redo','-','Find','Replace','-','SelectAll','RemoveFormat'],
	'/',
	['Bold','Italic','Underline','StrikeThrough','-','Subscript','Superscript'],
	['JustifyLeft','JustifyCenter','JustifyRight','JustifyFull'],
	['UnorderedList','OrderedList','-','Outdent','Indent'],
	['Link','Unlink','Anchor'],
	['FitWindow','Image',/*'Flash',*/'Table','Rule',/*'Smiley',*/'SpecialChar','PageBreak'], //,'UniversalKey'
	'/',
	['Style','FontFormat','FontName','FontSize'],
	['TextColor','BGColor']
] ;

==> egroupware_1.6.001+dfsg.orig.tar.gz: egroupware-1.6.001+dfsg/phpgwapi/js/fckeditor/fckeditor.egwconfig.js <==
FCKConfig.ToolbarSets["egw_simple"] = [
	['Bold','Italic','Underline'],
	['JustifyLeft','JustifyCenter','JustifyRight','JustifyFull'],
	['UnorderedList','OrderedList','Outdent','Indent','Undo','Redo'],
	['FitWindow'],
	'/',
	['FontFormat','FontName','FontSize'],
	['TextColor','BGColor'],
	['ShowBlocks','-','About']
] ;
FCKConfig.ToolbarSets["egw_simple_spellcheck"] = [
	['Bold','Italic','Underline'],
	['JustifyLeft','JustifyCenter','JustifyRight','JustifyFull'],
	['UnorderedList','OrderedList','Outdent','Indent','Undo','Redo'],
	['FitWindow','SpellCheck'],
	'/',
	['FontFormat','FontName','FontSize'],
	['TextColor','BGColor'],
	['ShowBlocks','-','About']
] ;
FCKConfig.ToolbarSets["egw_extended"] = [
	['Bold','Italic','Underline'],
	['JustifyLeft','JustifyCenter','JustifyRight','JustifyFull'],
	['UnorderedList','OrderedList','Outdent','Indent','Undo','Redo'],
	['Link','Unlink','Anchor'],
	['Find','Replace'],
	['FitWindow','Image','Table'],
	'/',
	['FontFormat','FontName','FontSize'],
	['TextColor','BGColor'],
	['ShowBlocks','-','About']
] ;
FCKConfig.ToolbarSets["egw_extended_spellcheck"] = [
	['Bold','Italic','Underline'],
	['JustifyLeft','JustifyCenter','JustifyRight','JustifyFull'],
	['UnorderedList','OrderedList','Outdent','Indent','Undo','Redo'],
	['Link','Unlink','Anchor'],
	['Find','Replace'],
	['FitWindow','SpellCheck','Image','Table'],
	'/',
	['FontFormat','FontName','FontSize'],
	['TextColor','BGColor'],
	['ShowBlocks','-','About']
] ;
FCKConfig.ToolbarSets["egw_advanced"] = [
	['Source','DocProps','-','Save','NewPage','Preview','-','Templates'],
	['Cut','Copy','Paste','PasteText','PasteWord','-','Print'],
	['Undo','Redo','-','Find','Replace','-','SelectAll','RemoveFormat'],
	'/',
	['Bold','Italic','Underline','StrikeThrough','-','Subscript','Superscript'],
	['JustifyLeft','JustifyCenter','JustifyRight','JustifyFull'],
	['UnorderedList','OrderedList','-','Outdent','Indent'],
	['Link','Unlink','Anchor'],
	['FitWindow','Image',/*'Flash',*/'Table','Rule',/*'Smiley',*/'SpecialChar','PageBreak'], //,'UniversalKey'
	'/',
	['Style','FontFormat','FontName','FontSize'],
	['TextColor','BGColor'],
	['ShowBlocks','-','About']
] ;
FCKConfig.ToolbarSets["egw_advanced_spellcheck"] = [
	['Source','DocProps','-','Save','NewPage','Preview','-','Templates'],
	['Cut','Copy','Paste','PasteText','PasteWord','-','Print','SpellCheck'],
	['Undo','Redo','-','Find','Replace','-','SelectAll','RemoveFormat'],
	'/',
	['Bold','Italic','Underline','StrikeThrough','-','Subscript','Superscript'],
	['JustifyLeft','JustifyCenter','JustifyRight','JustifyFull'],
	['UnorderedList','OrderedList','-','Outdent','Indent'],
	['Link','Unlink','Anchor'],
	['FitWindow','Image',/*'Flash',*/'Table','Rule',/*'Smiley',*/'SpecialChar','PageBreak'], //,'UniversalKey'
	'/',
	['Style','FontFormat','FontName','FontSize'],
	['TextColor','BGColor'],
	['ShowBlocks','-','About']
] ;
